@@ -1,6 +1,7 @@
 import datetime
 
 import mongoengine
+from mongoengine import EmbeddedDocumentField
 
 from insnail_ai_tools.mongodb.mixin import MultiDatabaseMixin, StrChoicesMixin
 from insnail_ai_tools.mongodb.model.wecom.wecom_personal_messge import UserRoleChoices
@@ -127,7 +128,9 @@ class MessageCheckResult(mongoengine.DynamicDocument, MultiDatabaseMixin):
     msg_mode = mongoengine.StringField(verbose_name="消息类型")
     msg_time = mongoengine.DateTimeField(verbose_name="消息时间")
 
-    illegal_list = mongoengine.ListField(IllegalMeta)
+    illegal_list = mongoengine.ListField(
+        EmbeddedDocumentField(IllegalMeta), verbose_name="违法列表"
+    )
 
     create_time = mongoengine.DateTimeField(
         verbose_name="创建时间", default=datetime.datetime.now
