@@ -5,15 +5,16 @@ from insnail_ai_tools.config import ApolloConfig, YamlConfig
 
 def test_apollo_config():
     class Config(ApolloConfig):
-        MONGO_URI: str = None
+        TEST_FLAG: int = 1
 
     config = Config(
-        "insnail-qa-robot",
+        "ai-comm-center",
         "http://10.0.0.176:8080",
         "default",
     )
     config.fetch()
-    assert bool(config.MONGO_URI) is True
+    print(config.TEST_FLAG)
+    assert config.TEST_FLAG == 10
 
 
 def test_yaml_config():
